Module sql

Module sql 

Functions

get_fk_union_config
Get the query conditions for a list of foreign-key related (parent/peer) records
in_them
Create a where clause for a column to be in a list of values
in_them_and
A combination of in_them and merge_q_configs with the link word “AND” See also:
in_them_clause
Create a where clause for a column to be in a list of values
merge_q_configs
Merge two where clauses and their parameters
standardize_q_config
Standardize the where clause and parameters for a SQL query

Type Aliases

WhereConfig
Used as inputs to generate where conditions for SQL queries
WhereConfigOwned
The owned version of WhereConfig, used as outputs, e.g., for functions that generate where conditions for SQL queries